@@ -23,7 +23,7 @@ use vars qw(@ISA %EXPORT_TAGS @EXPORT_OK $VERSION);
 
 @EXPORT_OK = ( @{$EXPORT_TAGS{'all'}} );
 
-$VERSION = '0.24_01';
+$VERSION = '0.24_02';
 
 bootstrap UUID $VERSION;
 
@@ -183,6 +183,12 @@ Creates a new string format UUID and returns it in a more Perlish way.
 Functionally the equivalent of calling B<generate()> and then B<unparse()>, but
 throwing away the intermediate binary UUID.
 
+=head1 UUID LIBRARY
+
+Note that on some systems external packages will need to be installed
+first. Notably, uuid-dev or uuid-devel on Debian and RedHat Linux,
+respectively, and their derivatives.
+
 =head1 EXPORTS
 
 All functions may be imported in the usual manner, either individually
